@@ -2,8 +2,8 @@ h = Hash()
 
 @export
 def set_h(k: str, v: int):
-    h.set(k, v)
+    h[k] = v
 
 @export
 def get_h(k: str):
-    return h.get(k)
+    return h[k]
